Introduction
============

A regular account is a user account, identified by an email address or username,
and protected by a password. The ``allauth.account`` app is responsible for
managing regular accounts. It supports:

- Authentication by username or email.

- Registration of new users, with custom signup form support.

- Email address management: both a simple change email address flow, and more
  elaborate flows with multiple email addresses (adding secondary, setting a
  primary) is supported.

- Password forgotten flow.

- Changing of the password.

- Email address verification flow.
